==> jc-1.4.0.tar.gz: gnu/xml/pipeline/TextConsumer.h <==
// public class gnu.xml.pipeline.TextConsumer

// class file dependencies
// @dep_class 1d73439a9676373b gnu_xml_pipeline_TextConsumer
// @dep_class d4916ea70623e353 gnu_xml_util_XMLWriter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_util_XMLWriter

#include "gnu/xml/util/XMLWriter.h"

#ifndef _JC_gnu_xml_pipeline_TextConsumer_H_
#define _JC_gnu_xml_pipeline_TextConsumer_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_ContentHandler$object;
struct _jc_org_xml_sax_DTDHandler$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_TextConsumer$sub_refs	_jc_gnu_xml_pipeline_TextConsumer$sub_refs;
typedef struct _jc_gnu_xml_pipeline_TextConsumer$sub_nonrefs	_jc_gnu_xml_pipeline_TextConsumer$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_TextConsumer$refs	_jc_gnu_xml_pipeline_TextConsumer$refs;
typedef struct _jc_gnu_xml_pipeline_TextConsumer$nonrefs	_jc_gnu_xml_pipeline_TextConsumer$nonrefs;
typedef struct _jc_gnu_xml_pipeline_TextConsumer$object	_jc_gnu_xml_pipeline_TextConsumer$object;

typedef const struct _jc_gnu_xml_pipeline_TextConsumer$vmethods	_jc_gnu_xml_pipeline_TextConsumer$vmethods;
typedef const struct _jc_gnu_xml_pipeline_TextConsumer$vtable	_jc_gnu_xml_pipeline_TextConsumer$vtable;
typedef const struct _jc_gnu_xml_pipeline_TextConsumer$vtype	_jc_gnu_xml_pipeline_TextConsumer$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_TextConsumer$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_gnu_xml_pipeline_TextConsumer$method$_init$514f7e161933236e(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_io_Writer$object *);
extern void _jc_gnu_xml_pipeline_TextConsumer$method$_init$da50cc87d69b9a3d(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_io_Writer$object *, jboolean);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_pipeline_TextConsumer$method$getContentHandler$6b9484894c8b3757(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *);
extern struct _jc_object *_jc_gnu_xml_pipeline_TextConsumer$method$getDTDHandler$b67582121ed88817(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_pipeline_TextConsumer$method$getProperty$ad67146a826fdaf8(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_TextConsumer$method_info$getContentHandler$6b9484894c8b3757;
extern _jc_method _jc_gnu_xml_pipeline_TextConsumer$method_info$getDTDHandler$b67582121ed88817;
extern _jc_method _jc_gnu_xml_pipeline_TextConsumer$method_info$getProperty$ad67146a826fdaf8;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_TextConsumer$vmethods {
	struct _jc_object	*(*getContentHandler$6b9484894c8b3757)(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *);
	struct _jc_object	*(*getDTDHandler$b67582121ed88817)(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *);
	struct _jc_java_lang_Object$object	*(*getProperty$ad67146a826fdaf8)(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_TextConsumer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_XMLWriter$vmethods	gnu_xml_util_XMLWriter;
	_jc_gnu_xml_pipeline_TextConsumer$vmethods	gnu_xml_pipeline_TextConsumer;
};

// Vtype
struct _jc_gnu_xml_pipeline_TextConsumer$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_TextConsumer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_TextConsumer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_TextConsumer$refs {
    _jc_gnu_xml_pipeline_TextConsumer$sub_refs	gnu_xml_pipeline_TextConsumer;
    _jc_gnu_xml_util_XMLWriter$sub_refs	gnu_xml_util_XMLWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_TextConsumer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_TextConsumer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_XMLWriter$sub_nonrefs	gnu_xml_util_XMLWriter;
    _jc_gnu_xml_pipeline_TextConsumer$sub_nonrefs	gnu_xml_pipeline_TextConsumer;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_TextConsumer$object {
	_jc_gnu_xml_pipeline_TextConsumer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_TextConsumer$vtype	*vtype;
	_jc_gnu_xml_pipeline_TextConsumer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_TextConsumer$vtype _jc_gnu_xml_pipeline_TextConsumer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_TextConsumer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_TextConsumer$class_object;

#endif	/* _JC_gnu_xml_pipeline_TextConsumer_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/TextConsumer.h <==
// public class gnu.xml.pipeline.TextConsumer

// class file dependencies
// @dep_class 1d73439a9676373b gnu_xml_pipeline_TextConsumer
// @dep_class d4916ea70623e353 gnu_xml_util_XMLWriter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_util_XMLWriter

#include "gnu/xml/util/XMLWriter.h"

#ifndef _JC_gnu_xml_pipeline_TextConsumer_H_
#define _JC_gnu_xml_pipeline_TextConsumer_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_ContentHandler$object;
struct _jc_org_xml_sax_DTDHandler$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_TextConsumer$sub_refs	_jc_gnu_xml_pipeline_TextConsumer$sub_refs;
typedef struct _jc_gnu_xml_pipeline_TextConsumer$sub_nonrefs	_jc_gnu_xml_pipeline_TextConsumer$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_TextConsumer$refs	_jc_gnu_xml_pipeline_TextConsumer$refs;
typedef struct _jc_gnu_xml_pipeline_TextConsumer$nonrefs	_jc_gnu_xml_pipeline_TextConsumer$nonrefs;
typedef struct _jc_gnu_xml_pipeline_TextConsumer$object	_jc_gnu_xml_pipeline_TextConsumer$object;

typedef const struct _jc_gnu_xml_pipeline_TextConsumer$vmethods	_jc_gnu_xml_pipeline_TextConsumer$vmethods;
typedef const struct _jc_gnu_xml_pipeline_TextConsumer$vtable	_jc_gnu_xml_pipeline_TextConsumer$vtable;
typedef const struct _jc_gnu_xml_pipeline_TextConsumer$vtype	_jc_gnu_xml_pipeline_TextConsumer$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_TextConsumer$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_TextConsumer$method$_init$514f7e161933236e(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_io_Writer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_TextConsumer$method$_init$da50cc87d69b9a3d(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_io_Writer$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_pipeline_TextConsumer$method$getContentHandler$6b9484894c8b3757(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_pipeline_TextConsumer$method$getDTDHandler$b67582121ed88817(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_pipeline_TextConsumer$method$getProperty$ad67146a826fdaf8(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_TextConsumer$method_info$getContentHandler$6b9484894c8b3757;
extern _jc_method _jc_gnu_xml_pipeline_TextConsumer$method_info$getDTDHandler$b67582121ed88817;
extern _jc_method _jc_gnu_xml_pipeline_TextConsumer$method_info$getProperty$ad67146a826fdaf8;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_TextConsumer$vmethods {
	struct _jc_object	*(*getContentHandler$6b9484894c8b3757)(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDTDHandler$b67582121ed88817)(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getProperty$ad67146a826fdaf8)(_jc_env *, struct _jc_gnu_xml_pipeline_TextConsumer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_TextConsumer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_XMLWriter$vmethods	gnu_xml_util_XMLWriter;
	_jc_gnu_xml_pipeline_TextConsumer$vmethods	gnu_xml_pipeline_TextConsumer;
};

// Vtype
struct _jc_gnu_xml_pipeline_TextConsumer$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_TextConsumer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_TextConsumer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_TextConsumer$refs {
    _jc_gnu_xml_pipeline_TextConsumer$sub_refs	gnu_xml_pipeline_TextConsumer;
    _jc_gnu_xml_util_XMLWriter$sub_refs	gnu_xml_util_XMLWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_TextConsumer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_TextConsumer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_XMLWriter$sub_nonrefs	gnu_xml_util_XMLWriter;
    _jc_gnu_xml_pipeline_TextConsumer$sub_nonrefs	gnu_xml_pipeline_TextConsumer;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_TextConsumer$object {
	_jc_gnu_xml_pipeline_TextConsumer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_TextConsumer$vtype	*vtype;
	_jc_gnu_xml_pipeline_TextConsumer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_TextConsumer$vtype _jc_gnu_xml_pipeline_TextConsumer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_TextConsumer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_TextConsumer$class_object;

#endif	/* _JC_gnu_xml_pipeline_TextConsumer_H_ */
